==> lstdataprocess128-1.3.0.tar.gz: lstdataprocess128-1.3.0/src/lstdpp128/Check.cpp <==
/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://www.osor.eu/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#include "Check.h"

using namespace std;

namespace lstdpp128 {

Check::Check() :
	_maxNumberOfChannels(0),
	_numberOfGoodEvents(0),
	_numberOfBadEvents(0),
	_numberOfEventsNotInserted(0),
	_onZeroBlock(false),
	_zeroCounter(0),
	_maxTime(0),
	_ordered(true) {
}

void Check::init() {

	_maxNumberOfChannels = (1 << MAX_BITS);

	_numberOfGoodEvents = 0;
	_numberOfBadEvents = 0;
	_numberOfEventsNotInserted = 0;

	_onZeroBlock = false;
	_zeroCounter = 0;
}

Check::~Check() {
}

int32_t Check::numberOfGoodEvents() const {
	return _numberOfGoodEvents;
}

int32_t Check::numberOfBadEvents() const {
	return _numberOfBadEvents;
}

int32_t Check::numberOfEventsNotInserted() const {
	return _numberOfEventsNotInserted;
}

time_type Check::maxTime() const {
	return _maxTime;
}

bool Check::isOrdered() const {
	return _ordered;
}

bool Check::checkEvent(Event const & event) {

	if (event.crate >= listModeContext.crateBoard.nbCrates) {
		cout << "event " << event << " is bad, crate error" << endl;
		return false;
	}

	if (event.board >= listModeContext.crateBoard.crates[event.crate].nbBoards) {
		cout << "event " << event << " is bad, board error" << endl;
		return false;
	}

	if (event.channel >= listModeContext.crateBoard.crates[event.crate].boards[event.board].nbChannels) {
		cout << "event " << event << " is bad, channel error" << endl;
		return false;
	}

	return true;
}

void Check::processBadEvent(Event const & event) {
	_numberOfBadEvents++;
}

void Check::processEvent(Event const & event) {
	_numberOfGoodEvents++;

	if (event.crate == 0 && event.channel == 0 && event.data[0] == 0 && event.data[1] == 0) {
		if (_onZeroBlock) {
			_zeroCounter++;
		} else {
			_onZeroBlock = true;
			_zeroCounter = 1;
		}
	} else {
		if (_onZeroBlock) {

			if (_zeroCounter > 1) {
				cout << "Zero block with " << _zeroCounter << " elements" << endl;
			}

			_onZeroBlock = false;
			_zeroCounter = 0;
		}
	}

	if (event.time() < _lastEvent.time()) {
		_ordered = false;
		//cout << event << " < " << _lastEvent << endl;
	}

	_lastEvent = event;

	if (event.time() > _maxTime) {
		_maxTime = event.time();
	}
}

void Check::processEvent(EventBlockArrayIterator const & e) {
	_numberOfGoodEvents++;
}

void Check::processEventNotInserted(Event const & event) {
	_numberOfGoodEvents++;
	_numberOfEventsNotInserted++;
}

void Check::finish() {
}

}

==> lstdataprocess128-1.3.2.tar.gz: lstdataprocess128-1.3.2/src/lstdpp128/Check.cpp <==
/*
 * Nomad Instrument Control Software
 *
 * Copyright 2011 Institut Laue-Langevin
 *
 * Licensed under the EUPL, Version 1.1 only (the "License");
 * You may not use this work except in compliance with the Licence.
 * You may obtain a copy of the Licence at:
 *
 * http://www.osor.eu/eupl
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the Licence for the specific language governing permissions and
 * limitations under the Licence.
 */

#include "Check.h"

using namespace std;

namespace lstdpp128 {

Check::Check() :
	_maxNumberOfChannels(0),
	_numberOfGoodEvents(0),
	_numberOfBadEvents(0),
	_numberOfEventsNotInserted(0),
	_onZeroBlock(false),
	_zeroCounter(0),
	_maxTime(0),
	_ordered(true) {
}

void Check::init() {

	_maxNumberOfChannels = (1 << MAX_BITS);

	_numberOfGoodEvents = 0;
	_numberOfBadEvents = 0;
	_numberOfEventsNotInserted = 0;

	_onZeroBlock = false;
	_zeroCounter = 0;
}

Check::~Check() {
}

int32_t Check::numberOfGoodEvents() const {
	return _numberOfGoodEvents;
}

int32_t Check::numberOfBadEvents() const {
	return _numberOfBadEvents;
}

int32_t Check::numberOfEventsNotInserted() const {
	return _numberOfEventsNotInserted;
}

time_type Check::maxTime() const {
	return _maxTime;
}

bool Check::isOrdered() const {
	return _ordered;
}

bool Check::checkEvent(Event const & event) {

	if (event.crate >= listModeContext.crateBoard.nbCrates) {
		cout << "event " << event << " is bad, crate error" << endl;
		return false;
	}

	if (event.board >= listModeContext.crateBoard.crates[event.crate].nbBoards) {
		cout << "event " << event << " is bad, board error" << endl;
		return false;
	}

	if (event.channel >= listModeContext.crateBoard.crates[event.crate].boards[event.board].nbChannels) {
		cout << "event " << event << " is bad, channel error" << endl;
		return false;
	}

	return true;
}

void Check::processBadEvent(Event const & event) {
	_numberOfBadEvents++;
}

void Check::processEvent(Event const & event) {
	_numberOfGoodEvents++;

	if (event.crate == 0 && event.channel == 0 && event.data[0] == 0 && event.data[1] == 0) {
		if (_onZeroBlock) {
			_zeroCounter++;
		} else {
			_onZeroBlock = true;
			_zeroCounter = 1;
		}
	} else {
		if (_onZeroBlock) {

			// Do not print the zero blocks as it is confusing.
//			if (_zeroCounter > 1) {
//				cout << "Zero block with " << _zeroCounter << " elements" << endl;
//			}

			_onZeroBlock = false;
			_zeroCounter = 0;
		}
	}

	if (event.time() < _lastEvent.time()) {
		_ordered = false;
		//cout << event << " < " << _lastEvent << endl;
	}

	_lastEvent = event;

	if (event.time() > _maxTime) {
		_maxTime = event.time();
	}
}

void Check::processEvent(EventBlockArrayIterator const & e) {
	_numberOfGoodEvents++;
}

void Check::processEventNotInserted(Event const & event) {
	_numberOfGoodEvents++;
	_numberOfEventsNotInserted++;
}

void Check::finish() {
}

}
